@@ -9,7 +9,7 @@ You should consider to install :mod:`Distribute` to run all tests with::
 
 """
 import unittest
-__author__ = "flanker"
+__author__ = 'Matthieu Gallet'
 # __copyright__ = "Copyright 2013, 19pouces.net"
 # __credits__ = "flanker"
 # __maintainer__ = "flanker"
